==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/handlers/IngressControllerHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.IngressControllerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.IngressController;
import io.fabric8.openshift.api.model.operator.v1.IngressControllerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class IngressControllerHandler implements ResourceHandler<IngressController, IngressControllerBuilder> {

  @Override
  public String getKind() {
    return IngressController.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public IngressController create(OkHttpClient client, Config config, String namespace, IngressController item) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public IngressController replace(OkHttpClient client, Config config, String namespace, IngressController item) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public IngressController reload(OkHttpClient client, Config config, String namespace, IngressController item) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public IngressControllerBuilder edit(IngressController item) {
    return new IngressControllerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, IngressController item) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, IngressController item, Watcher<IngressController> watcher) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, IngressController item, String resourceVersion, Watcher<IngressController> watcher) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, IngressController item, ListOptions options, Watcher<IngressController> watcher) {
  return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public IngressController waitUntilReady(OkHttpClient client, Config config, String namespace, IngressController item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public IngressController waitUntilCondition(OkHttpClient client, Config config, String namespace, IngressController item, Predicate<IngressController> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.0-sources.jar: io/fabric8/openshift/client/handlers/IngressControllerHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.IngressControllerOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.IngressController;
import io.fabric8.openshift.api.model.operator.v1.IngressControllerBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class IngressControllerHandler implements ResourceHandler<IngressController, IngressControllerBuilder> {

  @Override
  public String getKind() {
    return IngressController.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public IngressController create(OkHttpClient client, Config config, String namespace, IngressController item, boolean dryRun) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public IngressController replace(OkHttpClient client, Config config, String namespace, IngressController item, boolean dryRun) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public IngressController reload(OkHttpClient client, Config config, String namespace, IngressController item) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public IngressControllerBuilder edit(IngressController item) {
    return new IngressControllerBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, IngressController item, boolean dryRun) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, IngressController item, Watcher<IngressController> watcher) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, IngressController item, String resourceVersion, Watcher<IngressController> watcher) {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, IngressController item, ListOptions options, Watcher<IngressController> watcher) {
  return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public IngressController waitUntilReady(OkHttpClient client, Config config, String namespace, IngressController item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public IngressController waitUntilCondition(OkHttpClient client, Config config, String namespace, IngressController item, Predicate<IngressController> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new IngressControllerOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
